@@ -1,5 +1,5 @@
 /* libinfinity - a GObject-based infinote implementation
- * Copyright (C) 2007, 2008, 2009 Armin Burgmeier <armin@arbur.net>
+ * Copyright (C) 2007-2011 Armin Burgmeier <armin@arbur.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -24,6 +24,7 @@
 #include <libinfinity/common/inf-ip-address.h>
 #include <libinfinity/common/inf-standalone-io.h>
 #include <libinfinity/common/inf-io.h>
+#include <libinfinity/common/inf-protocol.h>
 
 #include <string.h>
 
@@ -32,7 +33,9 @@ struct _InfTestBrowser {
   InfStandaloneIo* io;
   InfXmppConnection* conn;
   InfcBrowser* browser;
+#ifndef G_OS_WIN32
   int input_fd;
+#endif
 
   InfcBrowserIter cwd;
 };
@@ -226,8 +229,12 @@ inf_test_browser_input_cb(InfNativeSocket* fd,
 
   if(io & INF_IO_INCOMING)
   {
-    fgets(buffer, sizeof(buffer), stdin);
-    if(strlen(buffer) != sizeof(buffer) || buffer[sizeof(buffer)-2] == '\n')
+    if(fgets(buffer, sizeof(buffer), stdin) == NULL)
+    {
+      inf_standalone_io_loop_quit(test->io);
+    }
+    else if(strlen(buffer) != sizeof(buffer) ||
+            buffer[sizeof(buffer)-2] == '\n')
     {
       buffer[strlen(buffer)-1] = '\0';
 
@@ -276,7 +283,8 @@ inf_test_browser_notify_status_cb(GObject* object,
   {
     printf("Connection established\n");
 
-    inf_io_watch(
+#ifndef G_OS_WIN32
+    inf_io_add_watch(
       INF_IO(test->io),
       &test->input_fd,
       INF_IO_INCOMING | INF_IO_ERROR,
@@ -284,6 +292,7 @@ inf_test_browser_notify_status_cb(GObject* object,
       test,
       NULL
     );
+#endif
 
     /* Explore root node */
     infc_browser_iter_get_root(test->browser, &test->cwd);
@@ -292,7 +301,8 @@ inf_test_browser_notify_status_cb(GObject* object,
 
   if(infc_browser_get_status(test->browser) == INFC_BROWSER_DISCONNECTED)
   {
-    inf_standalone_io_loop_quit(test->io);
+    if(inf_standalone_io_loop_running(test->io))
+      inf_standalone_io_loop_quit(test->io);
   }
 }
 
@@ -309,13 +319,14 @@ main(int argc, char* argv[])
   g_type_init();
 
   test.io = inf_standalone_io_new();
+#ifndef G_OS_WIN32
   test.input_fd = STDIN_FILENO;
-
+#endif
   address = inf_ip_address_new_loopback4();
 
   error = NULL;
   tcp_conn =
-    inf_tcp_connection_new_and_open(INF_IO(test.io), address, 6523, &error);
+    inf_tcp_connection_new_and_open(INF_IO(test.io), address, inf_protocol_get_default_port(), &error);
 
   inf_ip_address_free(address);
 
