@@ -1,5 +1,5 @@
 /* libinfinity - a GObject-based infinote implementation
- * Copyright (C) 2007, 2008, 2009 Armin Burgmeier <armin@arbur.net>
+ * Copyright (C) 2007-2011 Armin Burgmeier <armin@arbur.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -32,7 +32,7 @@ received_cb(InfTcpConnection* connection,
 	    guint len,
 	    gpointer user_data)
 {
-  printf("\033[00;32m%.*s\033[00;00m", (int)len, (const char*)buffer);
+  printf("Received: \033[00;32m%.*s\033[00;00m", (int)len, (const char*)buffer);
   fflush(stdout);
 }
 
@@ -42,7 +42,7 @@ sent_cb(InfTcpConnection* connection,
 	guint len,
 	gpointer user_data)
 {
-  printf("\033[00;34m%.*s\033[00;00m", (int)len, (const char*)buffer);
+  printf("Sent: \033[00;34m%.*s\033[00;00m", (int)len, (const char*)buffer);
   fflush(stdout);
 }
 
